@@ -16,7 +16,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 
 # Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Ignore die signal.
 $SIG{__DIE__} = 'IGNORE';
@@ -152,22 +152,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Error::Pure>,
-L<Error::Pure::AllError>,
-L<Error::Pure::Always>,
-L<Error::Pure::Die>,
-L<Error::Pure::Error>,
-L<Error::Pure::ErrorList>,
-L<Error::Pure::HTTP::AllError>,
-L<Error::Pure::HTTP::Error>,
-L<Error::Pure::HTTP::ErrorList>,
-L<Error::Pure::HTTP::JSON>,
-L<Error::Pure::HTTP::Print>,
-L<Error::Pure::JSON::Advance>,
-L<Error::Pure::NoDie>,
-L<Error::Pure::Output::JSON>,
-L<Error::Pure::Output::Text>,
-L<Error::Pure::Utils>.
+=over
+
+=item L<Task::Error::Pure>
+
+Install the Error::Pure modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -186,6 +177,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
